@@ -3,6 +3,7 @@ import time
 import json
 import requests
 import csle_common.constants.constants as constants
+import csle_collector.constants.constants as collector_constants
 import csle_ryu.constants.constants as ryu_constants
 from csle_common.dao.emulation_config.emulation_env_config import EmulationEnvConfig
 from csle_common.dao.emulation_config.sdn_controller_config import SDNControllerConfig
@@ -113,8 +114,8 @@ class SDNControllerManager:
         response = requests.put(
             f"{constants.HTTP.HTTP_PROTOCOL_PREFIX}{controller_ip}:{controller_web_port}"
             f"{ryu_constants.RYU.START_PRODUCER_HTTP_RESOURCE}",
-            data=json.dumps({ryu_constants.KAFKA.BOOTSTRAP_SERVERS_PROPERTY: kafka_ip,
-                             ryu_constants.KAFKA.TIME_STEP_LEN_SECONDS: time_step_len}))
+            data=json.dumps({collector_constants.KAFKA.BOOTSTRAP_SERVERS_PROPERTY: kafka_ip,
+                             ryu_constants.RYU.TIME_STEP_LEN_SECONDS: time_step_len}))
         assert response.status_code == 200
         Logger.__call__().get_logger().info("Kafka producer started successfully")
 
